@@ -1,3 +1,5 @@
 from .main import Lightning
 from .session import Session
-from .visualization import Visualization
\ No newline at end of file
+from .visualization import Visualization
+from .types.plots import *
+from .types.images import *
\ No newline at end of file
