@@ -1,10 +1,9 @@
 import requests
-import os
-import time
 import json
 from visualization import Visualization
 import webbrowser
 
+
 class Session(object):
     name = None
     visualizations = []
@@ -21,17 +20,14 @@ class Session(object):
             return self.name
         return str(self.id)
 
-
     def create_visualization(self, data=None, images=None, type=None):
         viz = Visualization.create(session=self, data=data, images=images, type=type)
         self.visualizations.append(viz)
         return viz
 
-
     def open(self):
         webbrowser.open(self.host + '/sessions/' + str(self.id) + '/feed/')
 
-
     @classmethod
     def create(cls, host, name=None):
         url = host + '/sessions/'
